Bu modulu burclar hakkinda gundelik bir sekilde bilgi alin diye yaptim ve sizler için kullanima sunuyorum.
Modulun kullanimi asiri basit:


```
Ornek Kullanim:

from burclar import burclar

yay = burclar.yay() #Buraya yay yerine burclarin adini yazarak istediginiz bilgiyi alabilirsiniz.

print(yay) # Konsola çiktisini verir.

"""
Gundelik olarak her gun kendini duzenler ve sadece burc yorum kismini size verir.

"""


```
Bunun haricinde bir kullanimi yoktur. yay yazan yerlere farkli burclari yazarak bilgiler alabilirsiniz.

Burclar:

-terazi
-boga
-yay
-akrep
-kova
-aslan
-ikizler
-balik 
-koc
-yengec
-basak
-oglak

Modulu kullandiginiz için tesekkur ederim , en kisa zamanda daha gelismisini sizlerin huzuruna sunacagim.